# Jacobian

::: asdex.jacobian
::: asdex.value_and_jacobian
::: asdex.jacobian_from_coloring
::: asdex.value_and_jacobian_from_coloring
::: asdex.jacobian_coloring
::: asdex.jacobian_coloring_from_sparsity
::: asdex.jacobian_sparsity
::: asdex.check_jacobian_correctness
::: asdex.VerificationError

---

::: asdex.JacobianMode
